@@ -134,6 +134,10 @@ parse_provider (xmlTextReaderPtr reader, AgProvider *provider)
             {
                 ok = _ag_xml_dup_element_data (reader, &provider->plugin_name);
             }
+            else if (strcmp (name, "single-account") == 0)
+            {
+                ok = _ag_xml_get_boolean (reader, &provider->single_account);
+            }
             else if (strcmp (name, "template") == 0)
             {
                 ok = parse_template (reader, provider);
@@ -420,6 +424,27 @@ ag_provider_get_plugin_name (AgProvider *provider)
     return provider->plugin_name;
 }
 
+/**
+ * ag_provider_get_single_account:
+ * @provider: the #AgProvider.
+ *
+ * Tell whether the provider doesn't support creating more than one account.
+ * Note that libaccounts itself does not enforce preventing the creation of
+ * multiple accounts when this flag is set: the flag is only informative, and
+ * its implementation is left to the client.
+ *
+ * Returns: %FALSE if multiple accounts can be created from this provider,
+ * %TRUE otherwise.
+ *
+ * Since: 1.14
+ */
+gboolean
+ag_provider_get_single_account (AgProvider *provider)
+{
+    g_return_val_if_fail (provider != NULL, NULL);
+    return provider->single_account;
+}
+
 /**
  * ag_provider_get_file_contents:
  * @provider: the #AgProvider.
