@@ -146,7 +146,7 @@ parse_service (xmlTextReaderPtr reader, AgService *service)
             }
             else if (strcmp (name, "type_data") == 0)
             {
-                static const gchar *element = "<type_data";
+                static const gchar element[] = "<type_data";
                 gsize offset;
 
                 /* find the offset in the file where this element begins */
@@ -475,6 +475,9 @@ gboolean ag_service_has_tag (AgService *service, const gchar *tag)
 {
     g_return_val_if_fail (service != NULL, FALSE);
 
+    if (!service->file_data)
+        _ag_service_load_from_file (service);
+
     if (service->tags == NULL)
         copy_tags_from_type (service);
 
@@ -496,6 +499,9 @@ GList *ag_service_get_tags (AgService *service)
 {
     g_return_val_if_fail (service != NULL, NULL);
 
+    if (!service->file_data)
+        _ag_service_load_from_file (service);
+
     if (service->tags == NULL)
         copy_tags_from_type (service);
 
